#!/usr/local/bin/ksh
/**
* Copyright (c) 2008, Corey's Consulting LLC.  All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
* - Redistributions of source code must retain the above copyright notice,
*   this list of conditions and the following disclaimer.
* - Redistributions in binary form must reproduce the above copyright
*   notice, this list of conditions and the following disclaimer in the
*   documentation and/or other materials provided with the distribution.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*/


###############################################################################
# check parameters

if [ $# -ne 4 -a $# -ne 5 ]
then
    echo ""
    echo " USAGE: $0 <dbName> <dbHost> <dbUser> <dbPass> [<dbPort>]"
    echo ""
    echo " where dbName is the database to backup"
    echo "       dbHost is the host the database is running on"
    echo "       dbUser is the user to login as"
    echo "       dbPass is the password to use"
    echo "       dbPort is the optional database port (defaults to 3306)"
    echo ""

    exit 1
fi

DB_NAME=$1
DB_HOST=$2
DB_USER=$3
DB_PASS=$4

if [ $# -eq 5 ]
then
    DB_PORT=$5
else
    DB_PORT=3306
fi

OUTFILE=backup.sql

###############################################################################
# backup database

echo -n " Backing up database ${DB_NAME}..."

mysqldump --user=${DB_USER} --password=${DB_PASS} -h ${DB_HOST} -P ${DB_PORT} \
    -v --add-drop-database -r "${OUTFILE}" ${DB_NAME} \
    > ${OUTFILE}.stdout 2>${OUTFILE}.stderr

if [ $? -ne 0 ]
then
    echo " "
    echo " --- MYSQL SERVER ERROR - POSSIBLY WRONG PASSWORD, OR USER NOT AUTHORIZED? ---"
    echo " "
    exit 1
fi

echo "done."

echo " Backup file: ${OUTFILE}"
echo " Standard Output: ${OUTFILE}.stdout"
echo " Standard Error : ${OUTFILE}.stderr"
echo " SUCCESS"

exit 0
