#!/usr/local/bin/ksh
/**
* Copyright (c) 2008, Corey's Consulting LLC.  All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
* - Redistributions of source code must retain the above copyright notice,
*   this list of conditions and the following disclaimer.
* - Redistributions in binary form must reproduce the above copyright
*   notice, this list of conditions and the following disclaimer in the
*   documentation and/or other materials provided with the distribution.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*/


###############################################################################
# check parameters

if [ $# -ne 5 -a $# -ne 6 ]
then
    echo ""
    echo " USAGE: $0 <sqlFile> <dbName> <dbHost> <dbUser> <dbPass> [<dbPort>]"
    echo ""
    echo " where sqlFile is the file to restore"
    echo "       dbName is the database to load"
    echo "       dbHost is the host the database is running on"
    echo "       dbUser is the user to login as"
    echo "       dbPass is the password to use"
    echo "       dbPort is the optional database port (defaults to 3306)"
    echo ""

    exit 1
fi

RESTORE_FILE=$1
DB_NAME=$2
DB_HOST=$3
DB_USER=$4
DB_PASS=$5

if [ $# -eq 6 ]
then
    DB_PORT=$6
else
    DB_PORT=3306
fi

###############################################################################
# restore database

echo -n " Restoring database ${DB_NAME}..."

mysql --user=${DB_USER} --password=${DB_PASS} -h ${DB_HOST} -v -v -v --database=${DB_NAME} --no-beep < ${RESTORE_FILE} > /dev/null

if [ $? -ne 0 ]
then
    echo " "
    echo " --- MYSQL SERVER ERROR - POSSIBLY WRONG PASSWORD, OR USER NOT AUTHORIZED? ---"
    echo " "
    exit 1
fi

echo "done."


exit 0
