#!/usr/local/bin/ksh
/**
* Copyright (c) 2008, Corey's Consulting LLC.  All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
* - Redistributions of source code must retain the above copyright notice,
*   this list of conditions and the following disclaimer.
* - Redistributions in binary form must reproduce the above copyright
*   notice, this list of conditions and the following disclaimer in the
*   documentation and/or other materials provided with the distribution.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*/


###############################################################################
# check parameters

if [ $# -ne 2 -a $# -ne 3 ]
then
    echo ""
    echo " USAGE: $0 <dbHost> <dbPass> [<dbPort>]"
    echo ""
    echo " where dbHost is the host the database is running on"
    echo "       dbPass is the root password"
    echo "       dbPort is the optional database port (defaults to 3306)"
    echo ""

    exit 1
fi

DB_HOST=$1
DB_PASS=$2

if [ $# -eq 3 ]
then
    DB_PORT=$3
else
    DB_PORT=3306
fi

###############################################################################
# execute SQL command

mysql -u root --password="${DB_PASS}" -h ${DB_HOST} -t -P ${DB_PORT} -e "SHOW DATABASES"
if [ $? -ne 0 ]
then
    echo " "
    echo " --- MYSQL SERVER ERROR - POSSIBLY WRONG PASSWORD, OR USER NOT AUTHORIZED? ---"
    echo " "
    exit 1
fi

exit 0
